<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ne">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="unfinished">हटाउनुहोस्</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished">पूर्णस्क्रीन</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished">स्लाइड शो</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished">प्रतिलिपि / कपी </translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished">मनपर्ने</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished">घडीको दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished">घडिको उल्टो दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="unfinished">वालपेपरको रूपमा सेट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished">फाइल म्यानेजरमा देखाउनु गर्नुहोस्</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished">फोटो जानकारी</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="unfinished">पुनर्स्थापना गर्नुहोस्</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished">निर्यात</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>नाम नभएको</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द गर्नुहोस्</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>सिर्जना गर्नुहोस्</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>नयाँ एल्बम</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>रद्द गर्नुहोस्</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाउनुहोस्</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>के तपाईं पक्का यो एल्बम मेट्न चाहनुहुन्छ?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>त्रश </translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>मनपर्ने</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>आयात गर्नुहोस्</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>त्रश </translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>मनपर्ने</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>वा फोटो यहाँ तान्नुहोस् </translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>सबै आयात गर्नुहोस्</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>यसमा आयात गर्नुहोस्:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>आयात गर्नुहोस्</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>प्रणाली डिस्क</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>ग्यालरी</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>डिस्क व्यस्त छ,अहिले निकाल्न सक्दैनौ </translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ठिक छ</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>नयाँ एल्बम</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द गर्नुहोस्</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>एल्बम</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>रद्द गर्नुहोस्</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>बदल्नुहोस्</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>निर्यात</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>चित्रहरु</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>डोकुमेन्टस </translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>डाउनलोडहरू</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>डेस्कटप</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>भिडियोहरू</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>म्युजिक </translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>नाम:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>यसमा बचत गर्नुहोस्:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>फोर्मत्: </translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>गुणस्तर:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>बचत गर्नुहोस्</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>गिफ </translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>अन्य स्थान छान्नुहोस्</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ठिक छ</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>फाइल नाम खाली हुन सक्दैन</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>पहिले नै अवस्थित छ। के तपाइँ यसलाई बदल्न चाहानुहुन्छ?</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>% १ ड्राइभ</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>खाली% १ डिस्क</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>% १ ईन्क्रिप्टेड</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>% १ खण्ड</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>बचत गर्नुहोस्</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>फोटोहरू निर्यात गर्नुहोस्</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द गर्नुहोस्</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>हटाउँदै ...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>पुनर्स्थापना गर्दै ...</translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>रद्द गर्नुहोस्</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाउनुहोस्</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this photo from the album?</source>
        <translation>के तपाइँ पक्का हुनुहुन्छ कि तपाइँ यस फोटोलाई एल्बमबाट हटाउन चाहानुहुन्छ?</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n photos from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Are you sure you want to delete this video from the album?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n videos from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n items from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>आधारभूत जानकारी</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>विवरण</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>आयात गर्नुहोस्</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>स्लाइड शो</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>नाम बदल्नुहोस्</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>निर्यात</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाउनुहोस्</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>उपकरण</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>ग्यालरी</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>एल्बमहरू</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>नयाँ एल्बम</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>फोटोहरू</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>पूर्णस्क्रीन</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>मद्दत</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>फाइल म्यानेजरमा देखाउनु गर्नुहोस्</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>स्लाइड शो</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>प्रतिलिपि / कपी </translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>वालपेपरको रूपमा सेट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>घडीको दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>घडिको उल्टो दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>अघिल्लो</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>अर्को</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>मनपर्ने</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>मन नपर्ने</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>एल्बम पुनःनामाकरण गर्नुहोस्</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>एल्बम &quot;% 1&quot; हटाईयो</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>सफलतापूर्वक &quot;% 1&quot; मा थपियो</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>आयात सफल भयो</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>आयात असफल भयो</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>निर्यात असफल भयो</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>निर्यात सफल भयो</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>सबै फोटोहरू</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation> समयरेखाहरु</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>एल्बमहरू</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>पूर्णस्क्रीन / स्लाइड शो बन्द गर्नुहोस्</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>सर्टकट देखाउनुहोस्</translation>
    </message>
    <message>
        <source>View</source>
        <translation>हेर्नुहोस्</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>सबै छान्नुहोस्</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>जुम इन गर्नुहोस्</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>जुम आउट गर्नुहोस्  </translation>
    </message>
    <message>
        <source>New album</source>
        <translation>नयाँ एल्बम</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>पेज उप / पृष्ठ माथि</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation> पेज डाउन  / पृष्ठ तल</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>सेटिंग्स</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>आयात गर्दै ...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">हटाउनुहोस्</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>फ्ल्यास</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>टाईप  / प्रकार </translation>
    </message>
    <message>
        <source>File size</source>
        <translation> फाइल साइज  / फाईल आकार</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>डिमेन्सनस  / आयाम</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>मिति कब्जा गरियो</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>मिति परिमार्जित</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>एक्सपोजर मोड</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>एक्सपोजर प्रोग्राम</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>एक्सपोजर समय</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>एपर्चर</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>फोकल लम्बाई</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>आईएसओ</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>अधिकतम एपर्चर</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>मिटरिंग मोड</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>सेतो सन्तुलन</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>फ्ल्यास क्षतिपूर्ति</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>क्यामेरा मोडेल</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>लेन्स मोडेल</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>कलरस्पेस</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>ट्याग</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>प्रणाली डिस्क</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>चयन गर्नुहोस्</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>अचयन गर्नुहोस्</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>% १ /% २ /%।</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>रद्द गर्नुहोस्</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>पुनर्स्थापना गर्नुहोस्</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाउनुहोस्</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>फोटोहरू</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>भिडियोहरू</translation>
    </message>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>मनपर्ने</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>घडिको उल्टो दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>घडीको दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>आयात गर्दै ...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>कुनै खोज परिणामहरू छैनन्</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>स्लाइड शो</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>खोज परिणामहरू</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>हेर्नुहोस्</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>पूर्णस्क्रीन</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>निर्यात</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>मनपर्ने</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>मन नपर्ने</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>घडीको दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>घडिको उल्टो दिशामा घुमाउनुहोस्</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>फाइल म्यानेजरमा देखाउनु गर्नुहोस्</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>वालपेपरको रूपमा सेट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाउनुहोस्</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>स्लाइड शो</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>प्रतिलिपि / कपी </translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>फोटो जानकारी</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>एल्बममा थप्नुहोस्</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>एल्बमबाट हटाउनुहोस्</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>पुनर्स्थापना गर्नुहोस्</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>नयाँ एल्बम</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>प्रिन्ट गर्नुहोस्</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished">दिनहरु</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished">आधारभूत जानकारी</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation type="unfinished">मिति परिमार्जित</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">टाईप  / प्रकार </translation>
    </message>
    <message>
        <source>File size</source>
        <translation type="unfinished"> फाइल साइज  / फाईल आकार</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished">मिति कब्जा गरियो</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
